#!/usr/bin/env ruby
require 'hildon'

class HildonSample < Hildon::Window
	
	def initialize
		# call the original constructor
		super
		# start with unfullscreen window
		@fullscreen = false
		# call key_pressed when a key is released
		signal_connect('key_release_event') { | w, e | key_pressed(w, e) }
		# call quit when window is destroyed
		signal_connect("destroy") { quit }
		# add content to the window
		create_content
		# create menuitems
		create_menu
		# show the window
		show_all
	end
	
	def create_content
		# adds a label to the window
		add(Gtk::Label.new("Hello world!"))
	end
	
	def create_menu
		# create a menu
		main = Gtk::Menu.new
		# define labels
		labels = ["Hello", "About", "Quit"]
		# define methods to call when items are clicked
		method_names = ["hello", "about", "quit"]
		# define icons for these items
		icons = [Gtk::Stock::ABOUT, Gtk::Stock::QUIT]
		# iterate over labels array and connect them to the methods and add icons
		labels.each_with_index do | label, i |
			item = Gtk::ImageMenuItem.new(label)
			item.image = Gtk::Image.new(icons[i],Gtk::IconSize::MENU)
			item.signal_connect( 'activate' ) { self.method(method_names[i]).call }
			main.append(item)
		end
		# add menu to window
		set_menu(main)
	end
	
	def hello
		notice("Hello world!")
	end
	
	def about
		Gtk::AboutDialog.show(self, {:authors => ["Janne Mäkinen <janne.makinen@surffi.fi>"], :documenters => ["Janne Mäkinen <janne.makinen@surffi.fi>"], :version => "0.1", :comments => "Ruby-Hildon sample app"})
	end
	
	def quit
		Gtk.main_quit
	end
	
	def toggle_fullscreen
		if !@fullscreen
			fullscreen
		else
			unfullscreen
		end
		@fullscreen = !@fullscreen
	end
	
	def notice(message)
		begin
			Hildon::Banner.show_information(self, nil, message)
		rescue Exception => e
			#puts e.message
		end
	end
	
	def key_pressed(widget, event)	
		if event.keyval == Gdk::Keyval::GDK_F6
			toggle_fullscreen
		elsif event.keyval == Gdk::Keyval::GDK_F7
			notice("Volume up")
		elsif event.keyval == Gdk::Keyval::GDK_F8
			notice("Volume down")
		elsif event.keyval == Gdk::Keyval::GDK_Escape
			notice("Esc")
		elsif event.keyval == Gdk::Keyval::GDK_Return
			notice("Return")
		elsif event.keyval == Gdk::Keyval::GDK_Up
			notice("Up")
		elsif event.keyval == Gdk::Keyval::GDK_Down
			notice("Down")
		elsif event.keyval == Gdk::Keyval::GDK_Right
			notice("Right")
		elsif event.keyval == Gdk::Keyval::GDK_Left
			notice("Left")
		end
		return false
	end
	
end

if $0 == __FILE__
	GLib.set_application_name("HildonSample")
	app =  Hildon::Program.new
	app.add_window(HildonSample.new)
	Gtk.main
 end
